**scipackage** is a Python package providing science calculate.

## machinelearning-kit
  - **bestkmeans.c**
    find best k value for k-means cluster
  - **binning.c**
    binning vector to some phase
  - **correlate.c**
    calculate pearson of two vectors
  - **distance.c**
    calculate math distance such as euclid, hamming
  - **entropy.c**
    calculate the infomation entropy by log method
  - **fourstep.c**
    four step cluster
  - **gene.c**
    optimize method
  - **kdtree.c**
    KD Tree
  - **linear_regression.c**
    mutil meta linear regression
  - **louvain.c**
    louvain for graphic
  - **metric.c**
    metric index such as R2, F1
  - **pca.c**
    PCA
  - **seqsim.c**
    a cluster method
  - **similar.c**
    calculate the similar value of two vectors
  - **trie.c**
    Tries Tree
  - **weight.c**
    calculate the weight of factor

## natruelanguage-kit
  - **entity.c**
    entity recognize
  - **hash.c**
    Hash
  - **keyword.c**
    extract the keyword from sentence
  - **longest_common.c**
    longest common substr of two sentences
  - **process.c**
    process the netral language
  - **tagging.c**
    tag the word from sentence
  - **tokenize.c**
    make the sentence to separate word
  - **topic.c**
    extract the topic from sentence
  - **vocab.c**
    dictionary

## neuralnetwork-kit
  - **activate.c**
    layer of activate
  - **attention.c**
    Attention network
  - **bert.c**
    BERT
  - **crf.c**
    CRF
  - **dataset.c**
    dataset for torch
  - **dropout.c**
    layer of dropout
  - **esim.c**
    ESIM
  - **function.c**
    loss functions
  - **glove.c**
    Glove
  - **loss.c**
    loss functions
  - **lstm.c**
    LSTM
  - **lstm_crf.c**
    LSTM_CRF
  - **mask_linear.c**
    mask linear for torch
  - **optimize.c**
    optimize functions
  - **skip_gram.c**
    skip gram
  - **train.c**
    train prcess for torch

## timeseries-kit
  - **filter.c**
    filt the wave of time series data
  - **outlier.c**
    find the outlier of time series data
  - **segment.c**
    segment the time series data to some phase

